.. image:: https://readthedocs.org/projects/galaxie-eveloop/badge/?version=latest
   :target: https://galaxie-eveloop.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status
.. image:: https://gitlab.com/Tuuux/galaxie-eveloop/badges/master/pipeline.svg
   :target: https://gitlab.com/Tuuux/galaxie-eveloop/commits/master
   :alt: Pipeline status
.. image:: https://gitlab.com/Tuuux/galaxie-eveloop/badges/master/coverage.svg
   :target: https://gitlab.com/Tuuux/galaxie-eveloop/-/commits/master
   :alt: Coverage Status

=============================
Galaxie EveLoop documentation
=============================
.. figure::  https://galaxie-curses.readthedocs.io/_images/logo_galaxie.png
   :align:   center

Description
-----------
Galaxie Event Loop is a low tech main loop couple with a event bus.

After many years as kernel of Galaxie Curses project, it have been as decision to extract the main loop and the event bus.
Especially that because it work and be very small.


Links
-----
 * GitLab: https://gitlab.com/Tuuux/galaxie-eveloop/
 * Read the Doc: https://galaxie-eveloop.readthedocs.io/
 * PyPI: https://pypi.org/project/galaxie-eveloop/
 * PuPI Test: https://test.pypi.org/project/galaxie-eveloop/

Installation via pip
--------------------
Pypi

.. code:: bash

  pip install galaxie-eveloop

Pypi Test

.. code:: bash

  pip install -i https://test.pypi.org/simple/ galaxie-eveloop

